@@ -3,33 +3,33 @@
 #include "AT_R_Wrapper.h"
 
 void AT_run_CPPSC_method_R( const int*		number_of_field_components,
-	const float* E_MeV_u,
-	const int*	 particle_no,
-	const float* fluence_cm2_or_dose_Gy,
-	const int*	 material_no,
-	const int*	 stopping_power_source_no,
-	const int*	 rdd_model,
-	const float* rdd_parameters,
-	const int*	 er_model,
-	const int*	 gamma_model,
-	const float* gamma_parameters,
-	int*		 N2,
-	const float* fluence_factor,
-	const int*	 write_output,
-	const int*	 shrink_tails,
-	const float* shrink_tails_under,
-	const int*	 adjust_N2,
-	const int*	 lethal_events_mode,
-	float*		 relative_efficiency,
-	float*		 d_check,
-	float*		 S_HCP,
-	float*		 S_gamma,
-	float*		 mean_number_of_tracks_contrib,
-	float*		 start_number_of_tracks_contrib,
-	int*		 n_convolutions,
-	float*		 lower_Jensen_bound,
-	float*		 upper_Jensen_bound)
-{
+		const float*	E_MeV_u,
+		const int*		particle_no,
+		const float*	fluence_cm2_or_dose_Gy,
+		const int*		material_no,
+		const int*		stopping_power_source_no,
+		const int*		rdd_model,
+		const float*	rdd_parameters,
+		const int*		er_model,
+		const int*		gamma_model,
+		const float*	gamma_parameters,
+		int*			N2,
+		const float*	fluence_factor,
+		const int*		write_output,
+		const int*		shrink_tails,
+		const float*	shrink_tails_under,
+		const int*		adjust_N2,
+		const int*		lethal_events_mode,
+		float*			relative_efficiency,
+		float*			d_check,
+		float*			S_HCP,
+		float*			S_gamma,
+		float*			mean_number_of_tracks_contrib,
+		float*			start_number_of_tracks_contrib,
+		int*			n_convolutions,
+		float*			lower_Jensen_bound,
+		float*			upper_Jensen_bound
+){
   long i;
   const long number_of_field_components_long = (long)(*number_of_field_components);
   const long material_no_long = (long)(*material_no);
@@ -148,32 +148,32 @@ void AT_run_CPPSC_method_R( const int*		number_of_field_components,
 
 
 void AT_run_GSM_method_R( const int*		number_of_field_components,
-	const float* E_MeV_u,
-	const int*	 particle_no,
-	const float* fluence_cm2_or_dose_Gy,
-	const int*	 material_no,
-	const int*	 stopping_power_source_no,
-	const int*	 rdd_model,
-	const float* rdd_parameters,
-	const int*	 er_model,
-	const int*	 gamma_model,
-	const float* gamma_parameters,
-	const int*	 N_runs,
-	const int*	 write_output,
-	const int*	 nX,
-	const float* voxel_size_m,
-	const int*	 lethal_events_mode,
-	float*		 relative_efficiency,
-	float*		 d_check,
-	float*		 S_HCP,
-	float*		 S_gamma,
-	float*		 n_particles,
-	float*		 sd_relative_efficiency,
-	float*		 sd_d_check,
-	float*		 sd_S_HCP,
-	float*		 sd_S_gamma,
-	float*		 sd_n_particles)
-{
+		const float*	E_MeV_u,
+		const int*		particle_no,
+		const float*	fluence_cm2_or_dose_Gy,
+		const int*		material_no,
+		const int*		stopping_power_source_no,
+		const int*		rdd_model,
+		const float*	rdd_parameters,
+		const int*		er_model,
+		const int*		gamma_model,
+		const float*	gamma_parameters,
+		const int*		N_runs,
+		const int*		write_output,
+		const int*		nX,
+		const float*	voxel_size_m,
+		const int*		lethal_events_mode,
+		float*			relative_efficiency,
+		float*			d_check,
+		float*			S_HCP,
+		float*			S_gamma,
+		float*			n_particles,
+		float*			sd_relative_efficiency,
+		float*			sd_d_check,
+		float*			sd_S_HCP,
+		float*			sd_S_gamma,
+		float*			sd_n_particles
+){
   long i;
   const long number_of_field_components_long = (long)(*number_of_field_components);
   const long material_no_long = (long)(*material_no);
@@ -290,26 +290,26 @@ void AT_run_GSM_method_R( const int*		number_of_field_components,
 
 
 void AT_run_IGK_method_R( const int*		number_of_field_components,
-	const float* E_MeV_u,
-	const int*	 particle_no,
-	const float* fluence_cm2_or_dose_Gy,
-	const int*	 material_no,
-	const int*	 stopping_power_source_no,
-	const int*	 rdd_model,
-	const float* rdd_parameters,
-	const int*	 er_model,
-	const int*	 gamma_model,
-	const float* gamma_parameters,
-	const float* saturation_cross_section_factor,
-	const int*	 write_output,
-	float*		 relative_efficiency,
-	float*		 S_HCP,
-	float*		 S_gamma,
-	float*		 sI_cm2,
-	float*		 gamma_dose_Gy,
-	float*		 P_I,
-	float*		 P_g)
-{
+		const float*	E_MeV_u,
+		const int*		particle_no,
+		const float*	fluence_cm2_or_dose_Gy,
+		const int*		material_no,
+		const int*		stopping_power_source_no,
+		const int*		rdd_model,
+		const float*	rdd_parameters,
+		const int*		er_model,
+		const int*		gamma_model,
+		const float*	gamma_parameters,
+		const float*	saturation_cross_section_factor,
+		const int*		write_output,
+		float*			relative_efficiency,
+		float*			S_HCP,
+		float*			S_gamma,
+		float*			sI_cm2,
+		float*			gamma_dose_Gy,
+		float*			P_I,
+		float*			P_g
+){
   long i;
   const long number_of_field_components_long = (long)(*number_of_field_components);
   const long material_no_long = (long)(*material_no);
@@ -408,11 +408,11 @@ void AT_run_IGK_method_R( const int*		number_of_field_components,
 
 
 void AT_CSDA_range_m_R( const int*		number_of_particles,
-	const float* E_MeV_u,
-	const int*	 particle_no,
-	const int*	 material_no,
-	float*		 CSDA_range_m)
-{
+		const float*	E_MeV_u,
+		const int*		particle_no,
+		const int*		material_no,
+		float*			CSDA_range_m
+){
   long i;
   const long number_of_particles_long = (long)(*number_of_particles);
   const long material_no_long = (long)(*material_no);
@@ -451,11 +451,11 @@ void AT_CSDA_range_m_R( const int*		number_of_particles,
 
 
 void AT_CSDA_range_g_cm2_R( const int*		number_of_particles,
-	const float* E_MeV_u,
-	const int*	 particle_no,
-	const int*	 material_no,
-	float*		 CSDA_range_g_cm2)
-{
+		const float*	E_MeV_u,
+		const int*		particle_no,
+		const int*		material_no,
+		float*			CSDA_range_g_cm2
+){
   long i;
   const long number_of_particles_long = (long)(*number_of_particles);
   const long material_no_long = (long)(*material_no);
@@ -494,12 +494,12 @@ void AT_CSDA_range_g_cm2_R( const int*		number_of_particles,
 
 
 void AT_set_user_material_from_composition_R( const int*		n,
-	const float* density_g_cm3,
-	const int*	 A,
-	const int*	 Z,
-	const float* weight_fraction,
-	int*		 status)
-{
+		const float*	density_g_cm3,
+		const int*		A,
+		const int*		Z,
+		const float*	weight_fraction,
+		int*			status
+){
   long i;
   const long n_long = (long)(*n);
   const double density_g_cm3_double = (double)(*density_g_cm3);
@@ -540,11 +540,11 @@ void AT_set_user_material_from_composition_R( const int*		n,
 
 
 void AT_set_user_material_R( const float*	density_g_cm3,
-	const float* I_eV,
-	const float* average_A,
-	const float* average_Z,
-	int*		 status)
-{
+		const float*	I_eV,
+		const float*	average_A,
+		const float*	average_Z,
+		int*			status
+){
   const double density_g_cm3_double = (double)(*density_g_cm3);
   const double I_eV_double = (double)(*I_eV);
   const double average_A_double = (double)(*average_A);
@@ -569,11 +569,11 @@ void AT_set_user_material_R( const float*	density_g_cm3,
 
 
 void AT_I_eV_from_composition_R( const int*		n,
-	const int*	 Z,
-	const int*	 A,
-	const float* weight_fraction,
-	float*		 I_eV)
-{
+		const int*		Z,
+		const int*		A,
+		const float*	weight_fraction,
+		float*			I_eV
+){
   long i;
   const long n_long = (long)(*n);
 
@@ -612,11 +612,12 @@ void AT_I_eV_from_composition_R( const int*		n,
 
 
 void AT_effective_Z_from_composition_R( const int*		n,
-	const int*	 Z,
-	const float* weight_fraction,
-	const float* exponent,
-	float*		 effective_Z)
-{
+		const int*		Z,
+		const float*	weight_fraction,
+		const float*	electron_densities_cm3,
+		const float*	exponent,
+		float*			effective_Z
+){
   long i;
   const long n_long = (long)(*n);
   const double exponent_double = (double)(*exponent);
@@ -625,12 +626,14 @@ void AT_effective_Z_from_composition_R( const int*		n,
 //Allocate space for the input parameter.
   long* Z_long = (long*)calloc(n_long,sizeof(long));
   double* weight_fraction_double = (double*)calloc(n_long,sizeof(double));
+  double* electron_densities_cm3_double = (double*)calloc(n_long,sizeof(double));
 
 
 //Fill in the input parameter.
   for(i = 0 ; i < n_long; i++){
 	Z_long[i] = (long)Z[i];
 	weight_fraction_double[i] = (double)weight_fraction[i];
+	electron_densities_cm3_double[i] = (double)electron_densities_cm3[i];
   }
 
 //Define type-casted output variables
@@ -639,6 +642,7 @@ void AT_effective_Z_from_composition_R( const int*		n,
   AT_effective_Z_from_composition( n_long,
 	Z_long,
 	weight_fraction_double,
+	electron_densities_cm3_double,
 	exponent_double,
 	&effective_Z_double);
 
@@ -649,14 +653,15 @@ void AT_effective_Z_from_composition_R( const int*		n,
 //Free allocated space
   free(Z_long);
   free(weight_fraction_double);
+  free(electron_densities_cm3_double);
 }
 
 
 void AT_average_Z_from_composition_R( const int*		n,
-	const int*	 Z,
-	const float* weight_fraction,
-	float*		 average_Z)
-{
+		const int*		Z,
+		const float*	weight_fraction,
+		float*			average_Z
+){
   long i;
   const long n_long = (long)(*n);
 
@@ -691,10 +696,10 @@ void AT_average_Z_from_composition_R( const int*		n,
 
 
 void AT_average_A_from_composition_R( const int*		n,
-	const int*	 A,
-	const float* weight_fraction,
-	float*		 average_A)
-{
+		const int*		A,
+		const float*	weight_fraction,
+		float*			average_A
+){
   long i;
   const long n_long = (long)(*n);
 
@@ -729,12 +734,12 @@ void AT_average_A_from_composition_R( const int*		n,
 
 
 void AT_electron_density_m3_from_composition_R( const int*		n,
-	const float* density_g_cm3,
-	const int*	 Z,
-	const int*	 A,
-	const float* weight_fraction,
-	float*		 electron_density_m3)
-{
+		const float*	density_g_cm3,
+		const int*		Z,
+		const int*		A,
+		const float*	weight_fraction,
+		float*			electron_density_m3
+){
   long i;
   const long n_long = (long)(*n);
   const double density_g_cm3_double = (double)(*density_g_cm3);
@@ -775,11 +780,11 @@ void AT_electron_density_m3_from_composition_R( const int*		n,
 
 
 void AT_electron_density_m3_multi_R( const int*		n,
-	const float* density_g_cm3,
-	const float* average_Z,
-	const float* average_A,
-	float*		 electron_density_m3)
-{
+		const float*	density_g_cm3,
+		const float*	average_Z,
+		const float*	average_A,
+		float*			electron_density_m3
+){
   long i;
   const long n_long = (long)(*n);
 
@@ -820,9 +825,9 @@ void AT_electron_density_m3_multi_R( const int*		n,
 
 
 void AT_electron_density_m3_from_material_no_multi_R( const int*		n,
-	const int*	 material_no,
-	float*		 electron_density_m3)
-{
+		const int*		material_no,
+		float*			electron_density_m3
+){
   long i;
   const long n_long = (long)(*n);
 
@@ -855,15 +860,15 @@ void AT_electron_density_m3_from_material_no_multi_R( const int*		n,
 
 
 void AT_get_materials_data_R( const int*		number_of_materials,
-	const int*	 material_no,
-	float*		 density_g_cm3,
-	float*		 I_eV,
-	float*		 alpha_g_cm2_MeV,
-	float*		 p_MeV,
-	float*		 m_g_cm2,
-	float*		 average_A,
-	float*		 average_Z)
-{
+		const int*		material_no,
+		float*			density_g_cm3,
+		float*			I_eV,
+		float*			alpha_g_cm2_MeV,
+		float*			p_MeV,
+		float*			m_g_cm2,
+		float*			average_A,
+		float*			average_Z
+){
   long i;
   const long number_of_materials_long = (long)(*number_of_materials);
 
@@ -919,11 +924,159 @@ void AT_get_materials_data_R( const int*		number_of_materials,
 }
 
 
+void AT_I_eV_from_element_acronym_R( const int*		n,
+		char**		acronym,
+		float*			I,
+		int*			returnValue
+){
+  long i;
+  const long n_long = (long)(*n);
+
+
+//Allocate space for the results.
+  double* I_double = (double*)calloc(n_long,sizeof(double));
+
+  int returnValue_internal = 	AT_I_eV_from_element_acronym( n_long,
+	acronym,
+	I_double);
+
+//Results:
+
+	*returnValue = ( int )returnValue_internal;
+
+  for(i = 0 ; i < n_long; i++){
+	I[i] = (float)I_double[i];
+  }
+
+//Free allocated space
+  free(I_double);
+}
+
+
+void AT_density_g_cm3_from_element_acronym_R( const int*		n,
+		char**		acronym,
+		float*			density,
+		int*			returnValue
+){
+  long i;
+  const long n_long = (long)(*n);
+
+
+//Allocate space for the results.
+  double* density_double = (double*)calloc(n_long,sizeof(double));
+
+  int returnValue_internal = 	AT_density_g_cm3_from_element_acronym( n_long,
+	acronym,
+	density_double);
+
+//Results:
+
+	*returnValue = ( int )returnValue_internal;
+
+  for(i = 0 ; i < n_long; i++){
+	density[i] = (float)density_double[i];
+  }
+
+//Free allocated space
+  free(density_double);
+}
+
+
+void AT_atomic_weight_from_element_acronym_R( const int*		n,
+		char**		acronym,
+		float*			A,
+		int*			returnValue
+){
+  long i;
+  const long n_long = (long)(*n);
+
+
+//Allocate space for the results.
+  double* A_double = (double*)calloc(n_long,sizeof(double));
+
+  int returnValue_internal = 	AT_atomic_weight_from_element_acronym( n_long,
+	acronym,
+	A_double);
+
+//Results:
+
+	*returnValue = ( int )returnValue_internal;
+
+  for(i = 0 ; i < n_long; i++){
+	A[i] = (float)A_double[i];
+  }
+
+//Free allocated space
+  free(A_double);
+}
+
+
+void AT_element_acronym_from_Z_R( const int*		n,
+		int*			Z,
+		char**		acronym,
+		int*			returnValue
+){
+  long i;
+  const long n_long = (long)(*n);
+
+
+//Allocate space for the input parameter.
+  long* Z_long = (long*)calloc(n_long,sizeof(long));
+
+
+//Fill in the input parameter.
+  for(i = 0 ; i < n_long; i++){
+	Z_long[i] = (long)Z[i];
+  }
+
+  int returnValue_internal = 	AT_element_acronym_from_Z( n_long,
+	Z_long,
+	acronym);
+
+//Results:
+
+	*returnValue = ( int )returnValue_internal;
+
+
+//Free allocated space
+  free(Z_long);
+}
+
+
+void AT_Z_from_element_acronym_R( const int*		n,
+		char**		acronym,
+		int*			Z,
+		int*			returnValue
+){
+  long i;
+  const long n_long = (long)(*n);
+
+
+//Allocate space for the results.
+  long* Z_long = (long*)calloc(n_long,sizeof(long));
+
+  int returnValue_internal = 	AT_Z_from_element_acronym( n_long,
+	acronym,
+	Z_long);
+
+//Results:
+
+	*returnValue = ( int )returnValue_internal;
+
+  for(i = 0 ; i < n_long; i++){
+	Z[i] = (int)Z_long[i];
+  }
+
+//Free allocated space
+  free(Z_long);
+}
+
+
 void AT_nuclear_spin_from_particle_no_multi_R( const int*		n,
-	const int*	 particle_no,
-	float*		 I,
-	int*		 returnValue)
-{
+		const int*		particle_no,
+		float*			I,
+		int*			returnValue
+){
   long i;
   const long n_long = (long)(*n);
 
@@ -959,10 +1112,10 @@ void AT_nuclear_spin_from_particle_no_multi_R( const int*		n,
 
 
 void AT_Z_from_particle_no_R( const int*		n,
-	const int*	 particle_no,
-	int*		 Z,
-	int*		 returnValue)
-{
+		const int*		particle_no,
+		int*			Z,
+		int*			returnValue
+){
   long i;
   const long n_long = (long)(*n);
 
@@ -997,11 +1150,50 @@ void AT_Z_from_particle_no_R( const int*		n,
 }
 
 
+void AT_atomic_weight_from_Z_R( const int*		n,
+		const int*		Z,
+		float*			atomic_weight,
+		int*			returnValue
+){
+  long i;
+  const long n_long = (long)(*n);
+
+
+//Allocate space for the input parameter.
+  long* Z_long = (long*)calloc(n_long,sizeof(long));
+
+
+//Fill in the input parameter.
+  for(i = 0 ; i < n_long; i++){
+	Z_long[i] = (long)Z[i];
+  }
+
+//Allocate space for the results.
+  double* atomic_weight_double = (double*)calloc(n_long,sizeof(double));
+
+  int returnValue_internal = 	AT_atomic_weight_from_Z( n_long,
+	Z_long,
+	atomic_weight_double);
+
+//Results:
+
+	*returnValue = ( int )returnValue_internal;
+
+  for(i = 0 ; i < n_long; i++){
+	atomic_weight[i] = (float)atomic_weight_double[i];
+  }
+
+//Free allocated space
+  free(Z_long);
+  free(atomic_weight_double);
+}
+
+
 void AT_A_from_particle_no_R( const int*		n,
-	const int*	 particle_no,
-	int*		 A,
-	int*		 returnValue)
-{
+		const int*		particle_no,
+		int*			A,
+		int*			returnValue
+){
   long i;
   const long n_long = (long)(*n);
 
@@ -1037,11 +1229,11 @@ void AT_A_from_particle_no_R( const int*		n,
 
 
 void AT_particle_no_from_Z_and_A_R( const int*		n,
-	const int*	 Z,
-	const int*	 A,
-	int*		 particle_no,
-	int*		 returnValue)
-{
+		const int*		Z,
+		const int*		A,
+		int*			particle_no,
+		int*			returnValue
+){
   long i;
   const long n_long = (long)(*n);
 
@@ -1081,12 +1273,12 @@ void AT_particle_no_from_Z_and_A_R( const int*		n,
 
 
 void AT_WEPL_Bethe_multi_R( const int*		n,
-	const float* E_MeV_u,
-	const int*	 particle_no,
-	const int*	 material_no,
-	const float* slab_thickness_m,
-	float*		 WEPL)
-{
+		const float*	E_MeV_u,
+		const int*		particle_no,
+		const int*		material_no,
+		const float*	slab_thickness_m,
+		float*			WEPL
+){
   long i;
   const long n_long = (long)(*n);
   const long material_no_long = (long)(*material_no);
@@ -1127,12 +1319,12 @@ void AT_WEPL_Bethe_multi_R( const int*		n,
 
 
 void AT_CSDA_energy_after_slab_E_MeV_u_multi_R( const int*		n,
-	const float* E_initial_MeV_u,
-	const int*	 particle_no,
-	const int*	 material_no,
-	const float* slab_thickness_m,
-	float*		 E_final_MeV_u)
-{
+		const float*	E_initial_MeV_u,
+		const int*		particle_no,
+		const int*		material_no,
+		const float*	slab_thickness_m,
+		float*			E_final_MeV_u
+){
   long i;
   const long n_long = (long)(*n);
   const long material_no_long = (long)(*material_no);
@@ -1173,12 +1365,12 @@ void AT_CSDA_energy_after_slab_E_MeV_u_multi_R( const int*		n,
 
 
 void AT_CSDA_range_Bethe_g_cm2_multi_R( const int*		n,
-	const float* E_initial_MeV_u,
-	const float* E_final_MeV_u,
-	const int*	 particle_no,
-	const int*	 material_no,
-	float*		 CSDA_range_cm2_g)
-{
+		const float*	E_initial_MeV_u,
+		const float*	E_final_MeV_u,
+		const int*		particle_no,
+		const int*		material_no,
+		float*			CSDA_range_cm2_g
+){
   long i;
   const long n_long = (long)(*n);
   const long material_no_long = (long)(*material_no);
@@ -1221,13 +1413,13 @@ void AT_CSDA_range_Bethe_g_cm2_multi_R( const int*		n,
 
 
 void AT_Rutherford_SDCS_R( const float*	E_MeV_u,
-	const int*	 particle_no,
-	const int*	 material_no,
-	const int*	 n,
-	const float* T_MeV,
-	float*		 dsdT_m2_MeV,
-	int*		 returnValue)
-{
+		const int*		particle_no,
+		const int*		material_no,
+		const int*		n,
+		const float*	T_MeV,
+		float*			dsdT_m2_MeV,
+		int*			returnValue
+){
   long i;
   const double E_MeV_u_double = (double)(*E_MeV_u);
   const long particle_no_long = (long)(*particle_no);
@@ -1269,12 +1461,12 @@ void AT_Rutherford_SDCS_R( const float*	E_MeV_u,
 
 
 void AT_Stopping_Power_Mass_Bethe_MeV_cm2_g_multi_R( const int*		n,
-	const float* E_MeV_u,
-	const int*	 particle_no,
-	const int*	 material_no,
-	const float* E_restricted_keV,
-	float*		 Mass_Stopping_Power_MeV_cm2_g)
-{
+		const float*	E_MeV_u,
+		const int*		particle_no,
+		const int*		material_no,
+		const float*	E_restricted_keV,
+		float*			Mass_Stopping_Power_MeV_cm2_g
+){
   long i;
   const long n_long = (long)(*n);
   const long material_no_long = (long)(*material_no);
@@ -1315,12 +1507,12 @@ void AT_Stopping_Power_Mass_Bethe_MeV_cm2_g_multi_R( const int*		n,
 
 
 void AT_Stopping_Power_keV_um_multi_R( const int*		stopping_power_source_no,
-	const int*	 number_of_particles,
-	const float* E_MeV_u,
-	const int*	 particle_no,
-	const int*	 material_no,
-	float*		 Stopping_Power_keV_um)
-{
+		const int*		number_of_particles,
+		const float*	E_MeV_u,
+		const int*		particle_no,
+		const int*		material_no,
+		float*			Stopping_Power_keV_um
+){
   long i;
   const long stopping_power_source_no_long = (long)(*stopping_power_source_no);
   const long number_of_particles_long = (long)(*number_of_particles);
@@ -1361,12 +1553,12 @@ void AT_Stopping_Power_keV_um_multi_R( const int*		stopping_power_source_no,
 
 
 void AT_Stopping_Power_MeV_cm2_g_multi_R( const int*		stopping_power_source_no,
-	const int*	 number_of_particles,
-	const float* E_MeV_u,
-	const int*	 particle_no,
-	const int*	 material_no,
-	float*		 Stopping_Power_MeV_cm2_g)
-{
+		const int*		number_of_particles,
+		const float*	E_MeV_u,
+		const int*		particle_no,
+		const int*		material_no,
+		float*			Stopping_Power_MeV_cm2_g
+){
   long i;
   const long stopping_power_source_no_long = (long)(*stopping_power_source_no);
   const long number_of_particles_long = (long)(*number_of_particles);
@@ -1407,11 +1599,11 @@ void AT_Stopping_Power_MeV_cm2_g_multi_R( const int*		stopping_power_source_no,
 
 
 void AT_max_electron_ranges_m_R( const int*		number_of_particles,
-	const float* E_MeV_u,
-	const int*	 material_no,
-	const int*	 er_model,
-	float*		 max_electron_range_m)
-{
+		const float*	E_MeV_u,
+		const int*		material_no,
+		const int*		er_model,
+		float*			max_electron_range_m
+){
   long i;
   const long number_of_particles_long = (long)(*number_of_particles);
   const int material_no_long = (int)(*material_no);
@@ -1448,14 +1640,14 @@ void AT_max_electron_ranges_m_R( const int*		number_of_particles,
 
 
 void AT_mean_number_of_tracks_contrib_R( const int*		number_of_field_components,
-	const float* E_MeV_u,
-	const int*	 particle_no,
-	const float* fluence_cm2,
-	const int*	 material_no,
-	const int*	 er_model,
-	const int*	 stopping_power_source_no,
-	float*		 returnValue)
-{
+		const float*	E_MeV_u,
+		const int*		particle_no,
+		const float*	fluence_cm2,
+		const int*		material_no,
+		const int*		er_model,
+		const int*		stopping_power_source_no,
+		float*			returnValue
+){
   long i;
   const long number_of_field_components_long = (long)(*number_of_field_components);
   const long material_no_long = (long)(*material_no);
@@ -1497,14 +1689,14 @@ void AT_mean_number_of_tracks_contrib_R( const int*		number_of_field_components,
 
 
 void AT_stopping_power_ratio_R( const int*		number_of_field_components,
-	const float* E_MeV_u,
-	const int*	 particle_no,
-	const float* fluence_cm2,
-	const int*	 material_no,
-	const int*	 reference_material_no,
-	const int*	 stopping_power_source_no,
-	float*		 returnValue)
-{
+		const float*	E_MeV_u,
+		const int*		particle_no,
+		const float*	fluence_cm2,
+		const int*		material_no,
+		const int*		reference_material_no,
+		const int*		stopping_power_source_no,
+		float*			returnValue
+){
   long i;
   const long number_of_field_components_long = (long)(*number_of_field_components);
   const long material_no_long = (long)(*material_no);
@@ -1546,13 +1738,13 @@ void AT_stopping_power_ratio_R( const int*		number_of_field_components,
 
 
 void AT_dose_weighted_LET_MeV_cm2_g_R( const int*		number_of_field_components,
-	const float* E_MeV_u,
-	const int*	 particle_no,
-	const float* fluence_cm2,
-	const int*	 material_no,
-	const int*	 stopping_power_source_no,
-	float*		 returnValue)
-{
+		const float*	E_MeV_u,
+		const int*		particle_no,
+		const float*	fluence_cm2,
+		const int*		material_no,
+		const int*		stopping_power_source_no,
+		float*			returnValue
+){
   long i;
   const long number_of_field_components_long = (long)(*number_of_field_components);
   const long material_no_long = (long)(*material_no);
@@ -1592,13 +1784,13 @@ void AT_dose_weighted_LET_MeV_cm2_g_R( const int*		number_of_field_components,
 
 
 void AT_fluence_weighted_LET_MeV_cm2_g_R( const int*		number_of_field_components,
-	const float* E_MeV_u,
-	const int*	 particle_no,
-	const float* fluence_cm2,
-	const int*	 material_no,
-	const int*	 stopping_power_source_no,
-	float*		 returnValue)
-{
+		const float*	E_MeV_u,
+		const int*		particle_no,
+		const float*	fluence_cm2,
+		const int*		material_no,
+		const int*		stopping_power_source_no,
+		float*			returnValue
+){
   long i;
   const long number_of_field_components_long = (long)(*number_of_field_components);
   const long material_no_long = (long)(*material_no);
@@ -1638,13 +1830,13 @@ void AT_fluence_weighted_LET_MeV_cm2_g_R( const int*		number_of_field_components
 
 
 void AT_dose_weighted_E_MeV_u_R( const int*		number_of_field_components,
-	const float* E_MeV_u,
-	const int*	 particle_no,
-	const float* fluence_cm2,
-	const int*	 material_no,
-	const int*	 stopping_power_source_no,
-	float*		 returnValue)
-{
+		const float*	E_MeV_u,
+		const int*		particle_no,
+		const float*	fluence_cm2,
+		const int*		material_no,
+		const int*		stopping_power_source_no,
+		float*			returnValue
+){
   long i;
   const long number_of_field_components_long = (long)(*number_of_field_components);
   const long material_no_long = (long)(*material_no);
@@ -1684,10 +1876,10 @@ void AT_dose_weighted_E_MeV_u_R( const int*		number_of_field_components,
 
 
 void AT_fluence_weighted_E_MeV_u_R( const int*		number_of_field_components,
-	const float* E_MeV_u,
-	const float* fluence_cm2,
-	float*		 returnValue)
-{
+		const float*	E_MeV_u,
+		const float*	fluence_cm2,
+		float*			returnValue
+){
   long i;
   const long number_of_field_components_long = (long)(*number_of_field_components);
 
@@ -1719,13 +1911,13 @@ void AT_fluence_weighted_E_MeV_u_R( const int*		number_of_field_components,
 
 
 void AT_total_fluence_cm2_R( const int*		number_of_field_components,
-	const float* E_MeV_u,
-	const int*	 particle_no,
-	const float* D_Gy,
-	const int*	 material_no,
-	const int*	 stopping_power_source_no,
-	float*		 returnValue)
-{
+		const float*	E_MeV_u,
+		const int*		particle_no,
+		const float*	D_Gy,
+		const int*		material_no,
+		const int*		stopping_power_source_no,
+		float*			returnValue
+){
   long i;
   const long number_of_field_components_long = (long)(*number_of_field_components);
   const long material_no_long = (long)(*material_no);
@@ -1765,13 +1957,13 @@ void AT_total_fluence_cm2_R( const int*		number_of_field_components,
 
 
 void AT_total_D_Gy_R( const int*		number_of_field_components,
-	const float* E_MeV_u,
-	const int*	 particle_no,
-	const float* fluence_cm2,
-	const int*	 material_no,
-	const int*	 stopping_power_source_no,
-	float*		 returnValue)
-{
+		const float*	E_MeV_u,
+		const int*		particle_no,
+		const float*	fluence_cm2,
+		const int*		material_no,
+		const int*		stopping_power_source_no,
+		float*			returnValue
+){
   long i;
   const long number_of_field_components_long = (long)(*number_of_field_components);
   const long material_no_long = (long)(*material_no);
@@ -1811,11 +2003,11 @@ void AT_total_D_Gy_R( const int*		number_of_field_components,
 
 
 void AT_beam_par_technical_to_physical_R( const int*		n,
-	const float* N,
-	const float* FWHM_mm,
-	float*		 fluence_cm2,
-	float*		 sigma_cm)
-{
+		const float*	N,
+		const float*	FWHM_mm,
+		float*			fluence_cm2,
+		float*			sigma_cm
+){
   long i;
   const long n_long = (long)(*n);
 
@@ -1856,11 +2048,11 @@ void AT_beam_par_technical_to_physical_R( const int*		n,
 
 
 void AT_beam_par_physical_to_technical_R( const int*		n,
-	const float* fluence_cm2,
-	const float* sigma_cm,
-	float*		 N,
-	float*		 FWHM_mm)
-{
+		const float*	fluence_cm2,
+		const float*	sigma_cm,
+		float*			N,
+		float*			FWHM_mm
+){
   long i;
   const long n_long = (long)(*n);
 
@@ -1901,13 +2093,13 @@ void AT_beam_par_physical_to_technical_R( const int*		n,
 
 
 void AT_fluence_cm2_from_dose_Gy_R( const int*		n,
-	const float* E_MeV_u,
-	const int*	 particle_no,
-	const float* D_Gy,
-	const int*	 material_no,
-	const int*	 stopping_power_source_no,
-	float*		 fluence_cm2)
-{
+		const float*	E_MeV_u,
+		const int*		particle_no,
+		const float*	D_Gy,
+		const int*		material_no,
+		const int*		stopping_power_source_no,
+		float*			fluence_cm2
+){
   long i;
   const long n_long = (long)(*n);
   const long material_no_long = (long)(*material_no);
@@ -1952,13 +2144,13 @@ void AT_fluence_cm2_from_dose_Gy_R( const int*		n,
 
 
 void AT_dose_Gy_from_fluence_cm2_R( const int*		n,
-	const float* E_MeV_u,
-	const int*	 particle_no,
-	const float* fluence_cm2,
-	const int*	 material_no,
-	const int*	 stopping_power_source_no,
-	float*		 dose_Gy)
-{
+		const float*	E_MeV_u,
+		const int*		particle_no,
+		const float*	fluence_cm2,
+		const int*		material_no,
+		const int*		stopping_power_source_no,
+		float*			dose_Gy
+){
   long i;
   const long n_long = (long)(*n);
   const long material_no_long = (long)(*material_no);
@@ -2003,10 +2195,10 @@ void AT_dose_Gy_from_fluence_cm2_R( const int*		n,
 
 
 void AT_momentum_MeV_c_u_from_E_MeV_u_R( const int*		n,
-	const float* E_MeV_u,
-	float*		 momentum_MeV_c,
-	int*		 returnValue)
-{
+		const float*	E_MeV_u,
+		float*			momentum_MeV_c,
+		int*			returnValue
+){
   long i;
   const long n_long = (long)(*n);
 
@@ -2042,10 +2234,10 @@ void AT_momentum_MeV_c_u_from_E_MeV_u_R( const int*		n,
 
 
 void AT_max_E_transfer_MeV_R( const int*		n,
-	const float* E_MeV_u,
-	float*		 max_E_transfer_MeV,
-	int*		 returnValue)
-{
+		const float*	E_MeV_u,
+		float*			max_E_transfer_MeV,
+		int*			returnValue
+){
   long i;
   const long n_long = (long)(*n);
 
@@ -2081,11 +2273,11 @@ void AT_max_E_transfer_MeV_R( const int*		n,
 
 
 void AT_effective_charge_from_E_MeV_u_R( const int*		n,
-	const float* E_MeV_u,
-	const int*	 particle_no,
-	float*		 effective_charge,
-	int*		 returnValue)
-{
+		const float*	E_MeV_u,
+		const int*		particle_no,
+		float*			effective_charge,
+		int*			returnValue
+){
   long i;
   const long n_long = (long)(*n);
 
@@ -2125,13 +2317,13 @@ void AT_effective_charge_from_E_MeV_u_R( const int*		n,
 
 
 void AT_energy_straggling_after_slab_E_MeV_u_R( const int*		n,
-	const float* E_MeV_u,
-	const int*	 particle_no,
-	const int*	 material_no,
-	const float* slab_thickness_m,
-	const float* initial_sigma_E_MeV_u,
-	float*		 sigma_E_MeV_u)
-{
+		const float*	E_MeV_u,
+		const int*		particle_no,
+		const int*		material_no,
+		const float*	slab_thickness_m,
+		const float*	initial_sigma_E_MeV_u,
+		float*			sigma_E_MeV_u
+){
   long i;
   const long n_long = (long)(*n);
   const long material_no_long = (long)(*material_no);
@@ -2176,11 +2368,11 @@ void AT_energy_straggling_after_slab_E_MeV_u_R( const int*		n,
 
 
 void AT_energy_straggling_MeV2_cm2_g_R( const int*		n,
-	const float* E_MeV_u,
-	const int*	 particle_no,
-	const int*	 material_no,
-	float*		 dsE2dz_MeV2_cm2_g)
-{
+		const float*	E_MeV_u,
+		const int*		particle_no,
+		const int*		material_no,
+		float*			dsE2dz_MeV2_cm2_g
+){
   long i;
   const long n_long = (long)(*n);
   const long material_no_long = (long)(*material_no);
@@ -2219,10 +2411,10 @@ void AT_energy_straggling_MeV2_cm2_g_R( const int*		n,
 
 
 void AT_gamma_from_E_R( const int*		n,
-	const float* E_MeV_u,
-	float*		 gamma,
-	int*		 returnValue)
-{
+		const float*	E_MeV_u,
+		float*			gamma,
+		int*			returnValue
+){
   long i;
   const long n_long = (long)(*n);
 
@@ -2258,10 +2450,10 @@ void AT_gamma_from_E_R( const int*		n,
 
 
 void AT_E_MeV_u_from_momentum_MeV_c_u_R( const int*		n,
-	const float* momentum_MeV_c_u,
-	float*		 E_MeV_u,
-	int*		 returnValue)
-{
+		const float*	momentum_MeV_c_u,
+		float*			E_MeV_u,
+		int*			returnValue
+){
   long i;
   const long n_long = (long)(*n);
 
@@ -2297,10 +2489,10 @@ void AT_E_MeV_u_from_momentum_MeV_c_u_R( const int*		n,
 
 
 void AT_E_from_beta_R( const int*		n,
-	const float* beta,
-	float*		 E_MeV_u,
-	int*		 returnValue)
-{
+		const float*	beta,
+		float*			E_MeV_u,
+		int*			returnValue
+){
   long i;
   const long n_long = (long)(*n);
 
@@ -2336,10 +2528,10 @@ void AT_E_from_beta_R( const int*		n,
 
 
 void AT_beta_from_E_R( const int*		n,
-	const float* E_MeV_u,
-	float*		 beta,
-	int*		 returnValue)
-{
+		const float*	E_MeV_u,
+		float*			beta,
+		int*			returnValue
+){
   long i;
   const long n_long = (long)(*n);
 
@@ -2375,17 +2567,17 @@ void AT_beta_from_E_R( const int*		n,
 
 
 void AT_r_RDD_m_R( const int*		n,
-	const float* D_RDD_Gy,
-	const float* E_MeV_u,
-	const int*	 particle_no,
-	const int*	 material_no,
-	const int*	 rdd_model,
-	const float* rdd_parameter,
-	const int*	 er_model,
-	const int*	 stopping_power_source_no,
-	float*		 r_RDD_m,
-	int*		 returnValue)
-{
+		const float*	D_RDD_Gy,
+		const float*	E_MeV_u,
+		const int*		particle_no,
+		const int*		material_no,
+		const int*		rdd_model,
+		const float*	rdd_parameter,
+		const int*		er_model,
+		const int*		stopping_power_source_no,
+		float*			r_RDD_m,
+		int*			returnValue
+){
   long i;
   const long n_long = (long)(*n);
   const double E_MeV_u_double = (double)(*E_MeV_u);
@@ -2444,17 +2636,17 @@ void AT_r_RDD_m_R( const int*		n,
 
 
 void AT_D_RDD_Gy_R( const int*		n,
-	const float* r_m,
-	const float* E_MeV_u,
-	const int*	 particle_no,
-	const int*	 material_no,
-	const int*	 rdd_model,
-	const float* rdd_parameter,
-	const int*	 er_model,
-	const int*	 stopping_power_source_no,
-	float*		 D_RDD_Gy,
-	int*		 returnValue)
-{
+		const float*	r_m,
+		const float*	E_MeV_u,
+		const int*		particle_no,
+		const int*		material_no,
+		const int*		rdd_model,
+		const float*	rdd_parameter,
+		const int*		er_model,
+		const int*		stopping_power_source_no,
+		float*			D_RDD_Gy,
+		int*			returnValue
+){
   long i;
   const long n_long = (long)(*n);
   const double E_MeV_u_double = (double)(*E_MeV_u);
@@ -2512,3 +2704,123 @@ void AT_D_RDD_Gy_R( const int*		n,
 }
 
 
+void AT_SPC_read_data_from_filename_fast_R( const char**	filename,
+		int*			n,
+		int*			depth_step,
+		float*			depth_g_cm2,
+		float*			E_MeV_u,
+		float*			DE_MeV_u,
+		int*			particle_no,
+		float*			fluence_cm2,
+		int*			returnValue
+){
+  long i;
+  int n_long = (int)(*n);
+
+
+//Allocate space for the results.
+  int* depth_step_long = (int*)calloc(n_long,sizeof(int));
+  double* depth_g_cm2_double = (double*)calloc(n_long,sizeof(double));
+  double* E_MeV_u_double = (double*)calloc(n_long,sizeof(double));
+  double* DE_MeV_u_double = (double*)calloc(n_long,sizeof(double));
+  long* particle_no_long = (long*)calloc(n_long,sizeof(long));
+  double* fluence_cm2_double = (double*)calloc(n_long,sizeof(double));
+
+  int returnValue_internal = 	AT_SPC_read_data_from_filename_fast( filename[0],
+	n_long,
+	depth_step_long,
+	depth_g_cm2_double,
+	E_MeV_u_double,
+	DE_MeV_u_double,
+	particle_no_long,
+	fluence_cm2_double);
+
+//Results:
+
+	*returnValue = ( int )returnValue_internal;
+
+  for(i = 0 ; i < n_long; i++){
+	depth_step[i] = (int)depth_step_long[i];
+	depth_g_cm2[i] = (float)depth_g_cm2_double[i];
+	E_MeV_u[i] = (float)E_MeV_u_double[i];
+	DE_MeV_u[i] = (float)DE_MeV_u_double[i];
+	particle_no[i] = (int)particle_no_long[i];
+	fluence_cm2[i] = (float)fluence_cm2_double[i];
+  }
+
+//Free allocated space
+  free(depth_step_long);
+  free(depth_g_cm2_double);
+  free(E_MeV_u_double);
+  free(DE_MeV_u_double);
+  free(particle_no_long);
+  free(fluence_cm2_double);
+}
+
+
+void AT_SPC_read_header_from_filename_fast_R( const char**	filename,
+		float*			E_MeV_u,
+		float*			peak_position_g_cm2,
+		int*			particle_no,
+		int*			material_no,
+		float*			normalisation,
+		int*			depth_steps_no,
+		int*			returnValue
+){
+  long i;
+
+
+//Define type-casted output variables
+	double E_MeV_u_double = 0;
+	double peak_position_g_cm2_double = 0;
+	long particle_no_long = 0;
+	int material_no_long = 0;
+	double normalisation_double = 0;
+	int depth_steps_no_long = 0;
+
+  int returnValue_internal = 	AT_SPC_read_header_from_filename_fast( filename[0],
+	&E_MeV_u_double,
+	&peak_position_g_cm2_double,
+	&particle_no_long,
+	&material_no_long,
+	&normalisation_double,
+	&depth_steps_no_long);
+
+//Results:
+
+	*returnValue = ( int )returnValue_internal;
+
+  *E_MeV_u = (float)E_MeV_u_double;
+
+  *peak_position_g_cm2 = (float)peak_position_g_cm2_double;
+
+  *particle_no = (int)particle_no_long;
+
+  *material_no = (int)material_no_long;
+
+  *normalisation = (float)normalisation_double;
+
+  *depth_steps_no = (int)depth_steps_no_long;
+
+
+//Free allocated space
+}
+
+
+void AT_SPC_get_number_of_bins_from_filename_fast_R( const char**	filename,
+		int*			returnValue
+){
+  long i;
+
+
+  long returnValue_internal = 	AT_SPC_get_number_of_bins_from_filename_fast( filename[0]);
+
+//Results:
+
+	*returnValue = ( int )returnValue_internal;
+
+
+//Free allocated space
+}
+
+
